@@ -1,6 +1,5 @@
-from __future__ import unicode_literals
 import re
-from six.moves.urllib_parse import urlparse, parse_qs
+from urllib.parse import urlparse, parse_qs
 
 from lxml.objectify import fromstring
 from requests.exceptions import HTTPError
