@@ -149,13 +149,13 @@ class ChangeLog:
         :param handle: An open and iterable (file) handle
         :type handle: Any derived object of :py:class:`io.IOBase`
         """
-        # pylint: disable=too-many-branches
+        # pylint: disable=too-many-branches,consider-using-with
         entry = self.entry_factory()
 
         if isinstance(handle, TextIOBase):
             handle.seek(0)
         elif isinstance(handle, (str, bytes)):
-            handle = open(handle, "r")
+            handle = open(handle, "r")  # pylint: disable=consider-using-with
         else:
             raise TypeError("Unexpected type for 'path': {}".format(
                 type(handle)))
